@@ -2005,8 +2005,10 @@ Will use HTML5 for this SASsession.""")
 
       code = "data sasdata2dataframe / view=sasdata2dataframe; set "+tabname+self._sb._dsopts(dsopts)+";\nformat "
 
-      my_fmts = kwargs.pop('my_fmts', False)
-      k_dts   = kwargs.pop('dtype',   None)
+      idx_col = kwargs.pop('index_col', False)
+      eng     = kwargs.pop('engine',    'c')
+      my_fmts = kwargs.pop('my_fmts',   False)
+      k_dts   = kwargs.pop('dtype',     None)
       if k_dts is None and my_fmts:
          print("my_fmts option only valid when dtype= is specified. Ignoring and using necessary formatting for data transfer.")
          my_fmts = False
@@ -2123,7 +2125,7 @@ Will use HTML5 for this SASsession.""")
                 self._log += logf
 
          csv.close()
-         df = pd.read_csv(tmpcsv, index_col=False, engine='c', dtype=dts, **kwargs)
+         df = pd.read_csv(tmpcsv, index_col=idx_col, engine=eng, dtype=dts, **kwargs)
       else:
          while True:
             try:
@@ -2151,7 +2153,7 @@ Will use HTML5 for this SASsession.""")
             if done and bail:
                break
 
-         df = pd.read_csv(tmpcsv, index_col=False, engine='c', dtype=dts, **kwargs)
+         df = pd.read_csv(tmpcsv, index_col=idx_col, engine=eng, dtype=dts, **kwargs)
 
       if tmpdir:
          tmpdir.cleanup()
@@ -2276,8 +2278,10 @@ Will use HTML5 for this SASsession.""")
       rdelim = "'"+'%02x' % ord(rowsep.encode(self.sascfg.encoding))+"'x"
       cdelim = "'"+'%02x' % ord(colsep.encode(self.sascfg.encoding))+"'x "
 
-      my_fmts = kwargs.pop('my_fmts', False)
-      k_dts   = kwargs.pop('dtype',   None)
+      idx_col = kwargs.pop('index_col', False)
+      eng     = kwargs.pop('engine',    'c')
+      my_fmts = kwargs.pop('my_fmts',   False)
+      k_dts   = kwargs.pop('dtype',     None)
       if k_dts is None and my_fmts:
          print("my_fmts option only valid when dtype= is specified. Ignoring and using necessary formatting for data transfer.")
          my_fmts = False
@@ -2464,7 +2468,7 @@ Will use HTML5 for this SASsession.""")
 
       quoting = kwargs.pop('quoting', 3)
 
-      df = pd.read_csv(tmpcsv, index_col=False, engine='c', header=None, names=varlist, 
+      df = pd.read_csv(tmpcsv, index_col=idx_col, engine=eng, header=None, names=varlist, 
                        sep=colsep, lineterminator=rowsep, dtype=dts, na_values=miss,
                        encoding=enc, quoting=quoting, **kwargs)
 
